diff mbox series

[API-NEXT,v1,1/2] api: pool: add min and max headroom in capability

Message ID 1504018808-9612-2-git-send-email-odpbot@yandex.ru
State New
Headers show
Series [API-NEXT,v1,1/2] api: pool: add min and max headroom in capability | expand

Commit Message

Github ODP bot Aug. 29, 2017, 3 p.m. UTC
From: Balasubramanian Manoharan <bala.manoharan@linaro.org>


Adds pool minimum and maximum headroom in pool capability

Signed-off-by: Balasubramanian Manoharan <bala.manoharan@linaro.org>

---
/** Email created from pull request 152 (bala-manoharan:pool_headroom)
 ** https://github.com/Linaro/odp/pull/152
 ** Patch: https://github.com/Linaro/odp/pull/152.patch
 ** Base sha: 91c0b58fc87ba0431241818758cea94438cd5498
 ** Merge commit sha: c6ab16c8354a9a96ad8d4001badf3a206e95bed7
 **/
 include/odp/api/spec/pool.h | 20 +++++++++++++++++++-
 1 file changed, 19 insertions(+), 1 deletion(-)
diff mbox series

Patch

diff --git a/include/odp/api/spec/pool.h b/include/odp/api/spec/pool.h
index 6fc5b6b4..787ca522 100644
--- a/include/odp/api/spec/pool.h
+++ b/include/odp/api/spec/pool.h
@@ -93,10 +93,17 @@  typedef struct odp_pool_capability_t {
 		/** Minimum packet level headroom length in bytes
 		 *
 		 * The minimum number of headroom bytes that newly created
 		 * packets have by default. The default apply to both ODP
 		 * packet input and user allocated packets.*/
 		uint32_t min_headroom;
 
+		/** Maximum packet level headroom length in bytes
+		 *
+		 * The maximum number of headroom bytes that newly created
+		 * packets can be configured. This value applies to both ODP
+		 * packet input and user allocated packets.*/
+		uint32_t max_headroom;
+
 		/** Minimum packet level tailroom length in bytes
 		 *
 		 * The minimum number of tailroom bytes that newly created
@@ -214,6 +221,17 @@  typedef struct odp_pool_param_t {
 			    defined by pool capability pkt.max_uarea_size.
 			    Specify as 0 if no user area is needed. */
 			uint32_t uarea_size;
+
+			/** Minimum Headroom size in bytes. Minimum number of
+			    bytes of space preceding packet data to reserve for
+			    use as headroom. This value will be used as a hint
+			    and implementation might configure a value of
+			    headroom greater than this value.
+			    Must not exceed the implementation defined
+			    'max_headroom' in odp_pool_capability().
+			    If the value is less than 'min_headroom' defined in
+			    'odp_pool_capability' then it will be ignored.*/
+			uint32_t min_headroom;
 		} pkt;
 
 		/** Parameters for timeout pools */
@@ -93,10 +93,17 @@  typedef struct odp_pool_capability_t {
 		 *
 		 * The minimum number of headroom bytes that newly created
-		 * packets have by default. The default apply to both ODP
+		 * packets can be configured. This value applies to both ODP
 		 * packet input and user allocated packets.*/
 		uint32_t min_headroom;